==> paraview-3.8.1.tbz: lib/paraview-3.8/vtkPVServerManagerKit.cmake <==
# Directory containing class headers.
SET(VTK_PVSERVERMANAGER_HEADER_DIR "${VTK_INSTALL_PREFIX}/include/paraview-3.8")

# Classes in vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_CLASSES
  "vtkDummyProcessModuleHelper"
  "vtkInitializationHelper"
  "vtkSMAnimationCueManipulatorProxy"
  "vtkSMAnimationCueProxy"
  "vtkSMAnimationPlayerProxy"
  "vtkSMAnimationSceneGeometryWriter"
  "vtkSMAnimationSceneImageWriter"
  "vtkSMAnimationSceneProxy"
  "vtkSMAnimationSceneWriter"
  "vtkSMApplication"
  "vtkSMArrayListDomain"
  "vtkSMArrayListInformationHelper"
  "vtkSMArrayRangeDomain"
  "vtkSMArraySelectionDomain"
  "vtkSMArraySelectionInformationHelper"
  "vtkSMAxesRepresentationProxy"
  "vtkSMBlockDeliveryRepresentationProxy"
  "vtkSMBlockDeliveryStrategy"
  "vtkSMBooleanDomain"
  "vtkSMBooleanKeyFrameProxy"
  "vtkSMBoundsDomain"
  "vtkSMBoxProxy"
  "vtkSMBoxRepresentationProxy"
  "vtkSMCameraConfigurationReader"
  "vtkSMCameraConfigurationWriter"
  "vtkSMCameraKeyFrameProxy"
  "vtkSMCameraLink"
  "vtkSMCameraManipulatorProxy"
  "vtkSMCameraProxy"
  "vtkSMCaveRenderViewProxy"
  "vtkSMClientDeliveryRepresentationProxy"
  "vtkSMClientDeliveryStrategyProxy"
  "vtkSMClientServerRenderSyncManagerHelper"
  "vtkSMClientServerRenderViewProxy"
  "vtkSMComparativeAnimationCueProxy"
  "vtkSMComparativeViewProxy"
  "vtkSMCompositeKeyFrameProxy"
  "vtkSMCompositeTreeDomain"
  "vtkSMCompoundSourceProxy"
  "vtkSMCompoundProxyDefinitionLoader"
  "vtkSMConnectionCleanerProxy"
  "vtkSMCSVExporterProxy"
  "vtkSMCubeAxesRepresentationProxy"
  "vtkSMDataLabelRepresentationProxy"
  "vtkSMDataRepresentationProxy"
  "vtkSMDataTypeDomain"
  "vtkSMDeserializer"
  "vtkSMDimensionsDomain"
  "vtkSMDistanceRepresentation2DProxy"
  "vtkSMDocumentation"
  "vtkSMDomain"
  "vtkSMDomainIterator"
  "vtkSMDoubleArrayInformationHelper"
  "vtkSMDoubleRangeDomain"
  "vtkSMDoubleVectorProperty"
  "vtkSMEnumerationDomain"
  "vtkSMExponentialKeyFrameProxy"
  "vtkSMExporterProxy"
  "vtkSMExtentDomain"
  "vtkSMFieldDataDomain"
  "vtkSMFileListDomain"
  "vtkSMFileSeriesReaderProxy"
  "vtkSMFixedTypeDomain"
  "vtkSMGlobalPropertiesManager"
  "vtkSMGlobalPropertiesLinkUndoElement"
  "vtkSMHardwareSelector"
  "vtkSMIceTCompositeViewProxy"
  "vtkSMIceTDesktopRenderViewProxy"
  "vtkSMIceTMultiDisplayRenderViewProxy"
  "vtkSMIdBasedProxyLocator"
  "vtkSMIdTypeVectorProperty"
  "vtkSMImageDataParallelStrategy"
  "vtkSMImageSliceRepresentationProxy"
  "vtkSMImageTextureProxy"
  "vtkSMImplicitPlaneProxy"
  "vtkSMImplicitPlaneRepresentationProxy"
  "vtkSMInformationHelper"
  "vtkSMInputArrayDomain"
  "vtkSMInputProperty"
  "vtkSMIdTypeArrayInformationHelper"
  "vtkSMIntArrayInformationHelper"
  "vtkSMInteractionUndoStackBuilder"
  "vtkSMIntRangeDomain"
  "vtkSMIntVectorProperty"
  "vtkSMKeyFrameAnimationCueManipulatorProxy"
  "vtkSMKeyFrameProxy"
  "vtkSMLinearAnimationCueManipulatorProxy"
  "vtkSMLink"
  "vtkSMLookupTableProxy"
  "vtkSMMaterialLoaderProxy"
  "vtkSMMultiProcessRenderView"
  "vtkSMNewWidgetRepresentationProxy"
  "vtkSMNullProxy"
  "vtkSMNumberOfComponentsDomain"
  "vtkSMNumberOfGroupsDomain"
  "vtkSMObject"
  "vtkSMOrderedPropertyIterator"
  "vtkSMOutlineRepresentationProxy"
  "vtkSMOutputPort"
  "vtkSMNetworkImageSourceProxy"
  "vtkSMPQStateLoader"
  "vtkSMPSWriterProxy"
  "vtkSMPluginManager"
  "vtkSMPluginProxy"
  "vtkSMPropertyAdaptor"
  "vtkSMProperty"
  "vtkSMPropertyHelper"
  "vtkSMPropertyIterator"
  "vtkSMNamedPropertyIterator"
  "vtkSMPropertyLink"
  "vtkSMPropertyModificationUndoElement"
  "vtkSMPropRepresentationProxy"
  "vtkSMProxy"
  "vtkSMProxyConfigurationReader"
  "vtkSMProxyConfigurationWriter"
  "vtkSMProxyDefinitionIterator"
  "vtkSMProxyGroupDomain"
  "vtkSMProxyIterator"
  "vtkSMProxyLink"
  "vtkSMProxyListDomain"
  "vtkSMProxyLocator"
  "vtkSMProxyManager"
  "vtkSMProxyManagerReviver"
  "vtkSMProxyProperty"
  "vtkSMProxyRegisterUndoElement"
  "vtkSMProxySelectionModel"
  "vtkSMProxyStateChangedUndoElement"
  "vtkSMProxyUnRegisterUndoElement"
  "vtkSMPythonTraceObserver"
  "vtkSMPVLookupTableProxy"
  "vtkSMPVRepresentationProxy"
  "vtkSMPWriterProxy"
  "vtkSMRampKeyFrameProxy"
  "vtkSMReaderFactory"
  "vtkSMRenderViewHelper"
  "vtkSMRenderViewProxy"
  "vtkSMRenderViewExporterProxy"
  "vtkSMRepresentationAnimationHelperProxy"
  "vtkSMRepresentationProxy"
  "vtkSMRepresentationStrategy"
  "vtkSMScalarBarActorProxy"
  "vtkSMScalarBarWidgetRepresentationProxy"
  "vtkSMScatterPlotArraysInformationHelper"
  "vtkSMScatterPlotRepresentationProxy"
  "vtkSMScatterPlotViewProxy"
  "vtkSMSelectionDeliveryRepresentationProxy"
  "vtkSMSelectionHelper"
  "vtkSMSelectionRepresentationProxy"
  "vtkSMServerFileListingProxy"
  "vtkSMServerProxyManagerReviver"
  "vtkSMServerSideAnimationPlayer"
  "vtkSMSILDomain"
  "vtkSMSILInformationHelper"
  "vtkSMSILModel"
  "vtkSMSimpleDoubleInformationHelper"
  "vtkSMSimpleIdTypeInformationHelper"
  "vtkSMSimpleIntInformationHelper"
  "vtkSMSimpleParallelStrategy"
  "vtkSMSimpleStrategy"
  "vtkSMSimpleStringInformationHelper"
  "vtkSMSinusoidKeyFrameProxy"
  "vtkSMSourceProxy"
  "vtkSMSpreadSheetRepresentationProxy"
  "vtkSMStateLoader"
  "vtkSMStateVersionControllerBase"
  "vtkSMStateVersionController"
  "vtkSMStringArrayHelper"
  "vtkSMStringListDomain"
  "vtkSMStringListRangeDomain"
  "vtkSMStringVectorProperty"
  "vtkSMSubPropertyIterator"
  "vtkSMSurfaceRepresentationProxy"
  "vtkSMTesting"
  "vtkSMTextSourceRepresentationProxy"
  "vtkSMTextWidgetRepresentationProxy"
  "vtkSMTimeAnimationCueProxy"
  "vtkSMTimeKeeperProxy"
  "vtkSMTimeRangeInformationHelper"
  "vtkSMTimeStepsInformationHelper"
  "vtkSMTransformProxy"
  "vtkSMTwoDRenderViewProxy"
  "vtkSMUndoElement"
  "vtkSMUndoRedoStateLoader"
  "vtkSMUndoStackBuilder"
  "vtkSMUndoStack"
  "vtkSMUniformGridParallelStrategy"
  "vtkSMUniformGridVolumeRepresentationProxy"
  "vtkSMUnstructuredDataParallelStrategy"
  "vtkSMUnstructuredGridParallelStrategy"
  "vtkSMUnstructuredGridVolumeRepresentationProxy"
  "vtkSMUtilities"
  "vtkSMUpdateInformationUndoElement"
  "vtkSMUpdateSuppressorProxy"
  "vtkSMVectorProperty"
  "vtkSMViewProxy"
  "vtkSMWidgetRepresentationProxy"
  "vtkSMWriterFactory"
  "vtkSMWriterProxy"
  "vtkSMXMLPVAnimationWriterProxy"
  "vtkSMDataSourceProxy"
  "vtkSMBarChartViewProxy"
  "vtkSMChartingArraysInformationHelper"
  "vtkSMChartNamedOptionsModelProxy"
  "vtkSMChartOptionsProxy"
  "vtkSMChartRepresentationProxy"
  "vtkSMChartViewProxy"
  "vtkSMContextNamedOptionsProxy"
  "vtkSMContextArraysInformationHelper"
  "vtkSMContextViewProxy"
  "vtkSMLineChartViewProxy"
  "vtkSMXYChartRepresentationProxy"
  "vtkSMXYChartViewProxy")

# Abstract classes in vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_CLASSES_ABSTRACT
  "vtkInitializationHelper"
  "vtkSMAnimationCueManipulatorProxy"
  "vtkSMAnimationSceneWriter"
  "vtkSMClientServerRenderSyncManagerHelper"
  "vtkSMDataRepresentationProxy"
  "vtkSMDomain"
  "vtkSMExporterProxy"
  "vtkSMInformationHelper"
  "vtkSMLink"
  "vtkSMMultiProcessRenderView"
  "vtkSMPropertyHelper"
  "vtkSMProxyManagerReviver"
  "vtkSMRepresentationProxy"
  "vtkSMRepresentationStrategy"
  "vtkSMStateVersionControllerBase"
  "vtkSMUndoElement"
  "vtkSMVectorProperty"
  "vtkSMChartViewProxy"
  "vtkSMContextViewProxy")

# Wrap-exclude classes in vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_CLASSES_WRAP_EXCLUDE
  "vtkSMPropertyHelper"
  "vtkSMRenderViewHelper")

# Set convenient variables to test each class.
FOREACH(class ${VTK_PVSERVERMANAGER_CLASSES})
  SET(VTK_CLASS_EXISTS_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERMANAGER_CLASSES_ABSTRACT})
  SET(VTK_CLASS_ABSTRACT_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERMANAGER_CLASSES_WRAP_EXCLUDE})
  SET(VTK_CLASS_WRAP_EXCLUDE_${class} 1)
ENDFOREACH(class)

==> paraview-3.10.1_1.tbz: lib/paraview-3.10/vtkPVServerManagerKit.cmake <==
# Directory containing class headers.
SET(VTK_PVSERVERMANAGER_HEADER_DIR "${VTK_INSTALL_PREFIX}/include/paraview-3.10")

# Classes in vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_CLASSES
  "vtkDummyProcessModuleHelper"
  "vtkInitializationHelper"
  "vtkSMAnimationCueManipulatorProxy"
  "vtkSMAnimationCueProxy"
  "vtkSMAnimationPlayerProxy"
  "vtkSMAnimationSceneGeometryWriter"
  "vtkSMAnimationSceneImageWriter"
  "vtkSMAnimationSceneProxy"
  "vtkSMAnimationSceneWriter"
  "vtkSMApplication"
  "vtkSMArrayListDomain"
  "vtkSMArrayListInformationHelper"
  "vtkSMArrayRangeDomain"
  "vtkSMArraySelectionDomain"
  "vtkSMArraySelectionInformationHelper"
  "vtkSMBooleanDomain"
  "vtkSMBooleanKeyFrameProxy"
  "vtkSMBoundsDomain"
  "vtkSMBoxProxy"
  "vtkSMBoxRepresentationProxy"
  "vtkSMCameraConfigurationReader"
  "vtkSMCameraConfigurationWriter"
  "vtkSMCameraKeyFrameProxy"
  "vtkSMCameraLink"
  "vtkSMCameraManipulatorProxy"
  "vtkSMCameraProxy"
  "vtkSMChartRepresentationProxy"
  "vtkSMComparativeAnimationCueProxy"
  "vtkSMComparativeViewProxy"
  "vtkSMCompositeKeyFrameProxy"
  "vtkSMCompositeTreeDomain"
  "vtkSMCompoundSourceProxy"
  "vtkSMCompoundProxyDefinitionLoader"
  "vtkSMConnectionCleanerProxy"
  "vtkSMContextArraysInformationHelper"
  "vtkSMContextNamedOptionsProxy"
  "vtkSMContextViewProxy"
  "vtkSMCSVExporterProxy"
  "vtkSMDataTypeDomain"
  "vtkSMDeserializer"
  "vtkSMDimensionsDomain"
  "vtkSMDistanceRepresentation2DProxy"
  "vtkSMDocumentation"
  "vtkSMDomain"
  "vtkSMDomainIterator"
  "vtkSMDoubleArrayInformationHelper"
  "vtkSMDoubleRangeDomain"
  "vtkSMDoubleVectorProperty"
  "vtkSMEnumerationDomain"
  "vtkSMExponentialKeyFrameProxy"
  "vtkSMExporterProxy"
  "vtkSMExtentDomain"
  "vtkSMFieldDataDomain"
  "vtkSMFileListDomain"
  "vtkSMFileSeriesReaderProxy"
  "vtkSMFixedTypeDomain"
  "vtkSMGlobalPropertiesManager"
  "vtkSMGlobalPropertiesLinkUndoElement"
  "vtkSMHardwareSelector"
  "vtkSMIdBasedProxyLocator"
  "vtkSMIdTypeVectorProperty"
  "vtkSMImageTextureProxy"
  "vtkSMImplicitPlaneProxy"
  "vtkSMImplicitPlaneRepresentationProxy"
  "vtkSMInformationHelper"
  "vtkSMInputArrayDomain"
  "vtkSMInputProperty"
  "vtkSMIdTypeArrayInformationHelper"
  "vtkSMIntArrayInformationHelper"
  "vtkSMInteractionUndoStackBuilder"
  "vtkSMIntRangeDomain"
  "vtkSMIntVectorProperty"
  "vtkSMKeyFrameAnimationCueManipulatorProxy"
  "vtkSMKeyFrameProxy"
  "vtkSMLinearAnimationCueManipulatorProxy"
  "vtkSMLink"
  "vtkSMLookupTableProxy"
  "vtkSMMaterialLoaderProxy"
  "vtkSMNewWidgetRepresentationProxy"
  "vtkSMNullProxy"
  "vtkSMNumberOfComponentsDomain"
  "vtkSMNumberOfGroupsDomain"
  "vtkSMObject"
  "vtkSMOrderedPropertyIterator"
  "vtkSMOutputPort"
  "vtkSMNetworkImageSourceProxy"
  "vtkSMParallelCoordinatesRepresentationProxy"
  "vtkSMPQStateLoader"
  "vtkSMPSWriterProxy"
  "vtkSMPluginManager"
  "vtkSMPluginProxy"
  "vtkSMPropertyAdaptor"
  "vtkSMProperty"
  "vtkSMPropertyHelper"
  "vtkSMPropertyIterator"
  "vtkSMNamedPropertyIterator"
  "vtkSMPropertyLink"
  "vtkSMPropertyModificationUndoElement"
  "vtkSMProxy"
  "vtkSMProxyConfigurationReader"
  "vtkSMProxyConfigurationWriter"
  "vtkSMProxyDefinitionIterator"
  "vtkSMProxyGroupDomain"
  "vtkSMProxyIterator"
  "vtkSMProxyLink"
  "vtkSMProxyListDomain"
  "vtkSMProxyLocator"
  "vtkSMProxyManager"
  "vtkSMProxyManagerReviver"
  "vtkSMProxyProperty"
  "vtkSMProxyRegisterUndoElement"
  "vtkSMProxySelectionModel"
  "vtkSMProxyStateChangedUndoElement"
  "vtkSMProxyUnRegisterUndoElement"
  "vtkSMPythonTraceObserver"
  "vtkSMPVLookupTableProxy"
  "vtkSMPVRepresentationProxy"
  "vtkSMPWriterProxy"
  "vtkSMRampKeyFrameProxy"
  "vtkSMReaderFactory"
  "vtkSMRenderViewProxy"
  "vtkSMRenderViewExporterProxy"
  "vtkSMRepresentationAnimationHelperProxy"
  "vtkSMRepresentationProxy"
  "vtkSMScalarBarActorProxy"
  "vtkSMScalarBarWidgetRepresentationProxy"
  "vtkSMSelectionHelper"
  "vtkSMSelectionRepresentationProxy"
  "vtkSMServerFileListingProxy"
  "vtkSMServerProxyManagerReviver"
  "vtkSMServerSideAnimationPlayer"
  "vtkSMSILDomain"
  "vtkSMSILInformationHelper"
  "vtkSMSILModel"
  "vtkSMSimpleDoubleInformationHelper"
  "vtkSMSimpleIdTypeInformationHelper"
  "vtkSMSimpleIntInformationHelper"
  "vtkSMSimpleStringInformationHelper"
  "vtkSMSinusoidKeyFrameProxy"
  "vtkSMSourceProxy"
  "vtkSMSpreadSheetRepresentationProxy"
  "vtkSMStateLoader"
  "vtkSMStateVersionControllerBase"
  "vtkSMStateVersionController"
  "vtkSMStringArrayHelper"
  "vtkSMStringListDomain"
  "vtkSMStringListRangeDomain"
  "vtkSMStringVectorProperty"
  "vtkSMSubPropertyIterator"
  "vtkSMTesting"
  "vtkSMTextSourceRepresentationProxy"
  "vtkSMTextWidgetRepresentationProxy"
  "vtkSMTimeAnimationCueProxy"
  "vtkSMTimeKeeperProxy"
  "vtkSMTimeRangeInformationHelper"
  "vtkSMTimeStepsInformationHelper"
  "vtkSMTransformProxy"
  "vtkSMTwoDRenderViewProxy"
  "vtkSMUndoElement"
  "vtkSMUndoRedoStateLoader"
  "vtkSMUndoStackBuilder"
  "vtkSMUndoStack"
  "vtkSMUniformGridVolumeRepresentationProxy"
  "vtkSMUnstructuredGridVolumeRepresentationProxy"
  "vtkSMUpdateInformationUndoElement"
  "vtkSMUtilities"
  "vtkSMVectorProperty"
  "vtkSMViewProxy"
  "vtkSMWidgetRepresentationProxy"
  "vtkSMWriterFactory"
  "vtkSMWriterProxy"
  "vtkSMXMLPVAnimationWriterProxy"
  "vtkSMDataSourceProxy")

# Abstract classes in vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_CLASSES_ABSTRACT
  "vtkInitializationHelper"
  "vtkSMAnimationCueManipulatorProxy"
  "vtkSMAnimationSceneWriter"
  "vtkSMDomain"
  "vtkSMExporterProxy"
  "vtkSMInformationHelper"
  "vtkSMLink"
  "vtkSMPropertyHelper"
  "vtkSMProxyManagerReviver"
  "vtkSMStateVersionControllerBase"
  "vtkSMUndoElement"
  "vtkSMVectorProperty")

# Wrap-exclude classes in vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_CLASSES_WRAP_EXCLUDE
  "vtkSMPropertyHelper")

# Wrap-special classes in vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_CLASSES_WRAP_SPECIAL)

# Wrappable non-class headers for vtkPVServerManager.
SET(VTK_PVSERVERMANAGER_WRAP_HEADERS)

# Set convenient variables to test each class.
FOREACH(class ${VTK_PVSERVERMANAGER_CLASSES})
  SET(VTK_CLASS_EXISTS_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERMANAGER_CLASSES_ABSTRACT})
  SET(VTK_CLASS_ABSTRACT_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERMANAGER_CLASSES_WRAP_EXCLUDE})
  SET(VTK_CLASS_WRAP_EXCLUDE_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERMANAGER_CLASSES_WRAP_SPECIAL})
  SET(VTK_CLASS_WRAP_SPECIAL_${class} 1)
ENDFOREACH(class)
